@@ -154,9 +154,12 @@ def update_options(kwargs):
                     raise TypeError("cores must be an int")
             else:
                 if key == "precision":
-                    if kwargs[key] not in ["I8", "I16", "I32", "F32", "F64"]:
+                    if kwargs[key] not in ["I8", "I16", "I32", "F32", "F64", "default"]:
                         raise ValueError("precision supplied is not valid!")
-                    session_info[key] = kwargs[key]
+                    if kwargs[key] == "default":
+                        session_info[key] = None 
+                    else:
+                        session_info[key] = kwargs[key]
                 else:
                     raise ValueError(kwargs[key] + " is not valid session info!")
         else:
@@ -1382,48 +1385,64 @@ class DataSet(object):
                 npoints=lambda x: x.npoints.astype("int")
             )
 
-            times = []
+            try:
 
-            ds = xr.open_dataset(ff, decode_times=False)
-            time_name = [x for x in ds.variables if "time" in x]
+                times = []
 
-            # get time name
+                ds = xr.open_dataset(ff, decode_times=False)
+                time_name = [x for x in ds.variables if "time" in x]
 
-            if len(time_name) > 0:
-                time_name = time_name[0]
-            else:
-                time_name = "time"
+                # get time name
 
-            for vv in cdo_result:
-                done = False
-                try:
-                    ds_times = ds[vv][time_name].values
-                except:
-                    times.append(None)
-                    done = True
+                if len(time_name) > 0:
+                    time_name = time_name[0]
+                else:
+                    time_name = "time"
 
-                if done is False:
+                for vv in cdo_result:
+                    done = False
                     try:
-                        n_times = len(ds_times)
+                        ds_times = ds[vv][time_name].values
                     except:
-                        n_times = 1
-                    times.append(n_times)
+                        times.append(None)
+                        done = True
 
-            df["ntimes"] = times
+                    if done is False:
+                        try:
+                            n_times = len(ds_times)
+                        except:
+                            n_times = 1
+                        times.append(n_times)
 
-            df = df.loc[
-                :,
-                [
-                    "variable",
-                    "ntimes",
-                    "npoints",
-                    "nlevels",
-                    "long_name",
-                    "unit",
-                    "data_type",
-                ],
-            ]
-            list_contents.append(df.assign(file=ff))
+                df["ntimes"] = times
+
+                df = df.loc[
+                    :,
+                    [
+                        "variable",
+                        "ntimes",
+                        "npoints",
+                        "nlevels",
+                        "long_name",
+                        "unit",
+                        "data_type",
+                    ],
+                ]
+                list_contents.append(df.assign(file=ff))
+            except:
+                warnings.warn("Potential data format issues identified. Consider running check!")
+                df = df.loc[
+                    :,
+                    [
+                        "variable",
+                        "npoints",
+                        "nlevels",
+                        "long_name",
+                        "unit",
+                        "data_type",
+                    ],
+                ]
+                list_contents.append(df.assign(file=ff))
 
         if len(list_contents) == 1:
             return list_contents[0].drop(columns="file")
@@ -1454,179 +1473,6 @@ class DataSet(object):
 
         return self.show_contents()
 
-        list_contents = []
-
-        use_names = True
-
-        for ff in self:
-            if "nctoolkit" in ff:
-                use_names = False
-
-        for ff in self:
-
-            dataset = Dataset(ff)
-
-            out = subprocess.run(
-                "cdo sinfon " + ff,
-                shell=True,
-                stdout=subprocess.PIPE,
-                stderr=subprocess.PIPE,
-            )
-            if "Unsupported file structure" in str(out.stderr):
-                for ff in self:
-                    remove_safe(ff)
-                    remove_protected(ff)
-                raise ValueError("Unsupported file structure. Check file using the check method.")
-            if "expandWildCards" in out.stderr.decode("utf-8"):
-                for ff in self:
-                    remove_safe(ff)
-                    remove_protected(ff)
-                raise ValueError(out.stderr.decode("utf-8"))
-            out = out.stdout.decode("utf-8")
-            out = out.split("\n")
-            out_inc = ["Grid coordinates :" in ff for ff in out]
-            var_det = []
-            i = 1
-            while True:
-                if out_inc[i]:
-                    break
-                i += 1
-                var_det.append(out[i - 1])
-
-            def split_var(x):
-                x = x.replace(":", "").split(" ")
-                x = [x for x in x if len(x) > 0]
-                new_x = []
-                include = False
-                for y in x[1:]:
-                    if y.isnumeric():
-                        include = True
-
-                    if include:
-                        new_x.append(y)
-                return new_x
-
-            def fix_head(x):
-                x = (
-                    x.replace(":", "")
-                    .replace("  ", " ")
-                    .replace("Parameter name", "variable")
-                )
-                x = x[x.find("Level") :].replace("  ", " ")
-                return x.split(" ")
-
-            def fix_type(x):
-                position = [m.start() for m in re.finditer(":", x)][-1]
-
-                return (
-                    x[: (position - 4)]
-                    + x[(position - 4) : position].replace(" ", "")
-                    + " "
-                    + x[(position):]
-                )
-
-            var_det[0] = fix_head(var_det[0])
-            for ii in range(1, len(var_det)):
-                var_det[ii] = fix_type(var_det[ii])
-                var_det[ii] = split_var(var_det[ii])
-
-            df = pd.DataFrame.from_records(var_det[1:], columns=var_det[0])
-            df = df.loc[:, ["Levels", "Points", "variable", "Dtype"]]
-            df = df.rename(
-                columns={"Levels": "nlevels", "Points": "npoints", "Dtype": "data_type"}
-            )
-
-            longs = None
-            units = None
-            longs = []
-
-            cdo_result = list(df.variable)
-
-            for x in cdo_result:
-                try:
-                    longs.append(dataset.variables[x].long_name)
-                except:
-                    longs.append(None)
-            units = []
-            for x in cdo_result:
-                try:
-                    units.append(dataset.variables[x].units)
-                except:
-                    units.append(None)
-
-            df = pd.DataFrame({"variable": cdo_result}).merge(df)
-
-            if longs is not None:
-                df["long_name"] = longs
-            if units is not None:
-                df["unit"] = units
-
-            df = df.assign(nlevels=lambda x: x.nlevels.astype("int")).assign(
-                npoints=lambda x: x.npoints.astype("int")
-            )
-
-            times = []
-
-            ds = xr.open_dataset(ff, decode_times=False)
-            time_name = [x for x in ds.variables if "time" in x]
-
-            # get time name
-
-            if len(time_name) > 0:
-                time_name = time_name[0]
-            else:
-                time_name = "time"
-
-            for vv in cdo_result:
-                done = False
-                try:
-                    ds_times = ds[vv][time_name].values
-                except:
-                    times.append(None)
-                    done = True
-
-                if done is False:
-                    try:
-                        n_times = len(ds_times)
-                    except:
-                        n_times = 1
-                    times.append(n_times)
-
-            df["ntimes"] = times
-
-            df = df.loc[
-                :,
-                [
-                    "variable",
-                    "ntimes",
-                    "npoints",
-                    "nlevels",
-                    "long_name",
-                    "unit",
-                    "data_type",
-                ],
-            ]
-            list_contents.append(df.assign(file=ff))
-
-        if len(list_contents) == 1:
-            return list_contents[0].drop(columns="file")
-
-        if use_names is False:
-            new_df = []
-            i = 1
-            for x in list_contents:
-                new_df.append(x.assign(file=f"file {i}"))
-                i += 1
-
-            new_df = pd.concat(new_df)
-
-            if len(set(new_df.file)) == 1:
-                return new_df.drop(columns="file")
-            else:
-                new_df = new_df.set_index("file")
-                return new_df
-        else:
-            return pd.concat(list_contents).set_index("file")
 
     @property
     def start(self):
