@@ -155,9 +155,6 @@ def regrid(self, grid=None, method="bil", recycle=False, **kwargs):
             grid_split[key], suppress_messages=True, thredds=self._thredds, checks = False
         )
 
-        if tracker._precision != "default":
-            tracker.set_precision(self._precision)
-
         weights_nc = temp_file("nc")
 
         cdo_command = (
