@@ -150,37 +150,6 @@ def as_missing(self, value=None):
 
     run_this(cdo_command, self, output="ensemble")
 
-def set_missing(self, value=None):
-    """
-    Set the missing value for a single number or a range
-
-    Parameters
-    -------------
-    value : 2 variable list or int/float
-        If int/float is provided, the missing value will be set to that.
-        If a list is provided, values between the two values (inclusive)
-        of the list are set to missing.
-    """
-    warnings.warn("set_missing is deprecated. Please us as_missing")
-
-    if value is None:
-        raise ValueError("Please supply missing value")
-
-    if (type(value) is float) or (type(value) is int):
-        value = [value, value]
-
-    if type(value) is not list:
-        raise TypeError("Please supply a list, int or float!")
-
-    for vv in value:
-        if (type(vv) is not float) and (type(vv) is not int):
-            raise TypeError(f"{vv} is not an int or float")
-
-    if type(value) is list:
-        cdo_command = f"cdo -setrtomiss,{str(value[0])},{str(value[1])}"
-
-    run_this(cdo_command, self, output="ensemble")
-
 
 def set_units(self, unit_dict=None):
     """
